#!/bin/bash
# ANAR+ radiance rendering and simulation script

################
# usage function

usage()
{
cat << EOF
usage: $0 options

This is the ANAR+ radiance rendering and simulation script 

OPTIONS:
	-h	
		Show this message
	-l
		generates 4 views in vector (.eps) format
	-v
		generates a 4 view image
	-r   
   		generates radiance rendering (using rpict)
	-s  
   		radiance simulation (using rtrace and input measuring points)  	 
	-f filename      
   		specifies optional filename
EOF
}

#################
# option parsing

lineflag=
viewflag=
renderflag=
simflag=
filename="out"
while getopts 'lvrsf:' OPTION
do
	case $OPTION in
	l)	lineflag=1
  			;;
	v)	viewflag=1
  			;;
	r)	renderflag=1
  			;;
	s)	simflag=1
			;;
	f)	filename="$OPTARG"
			;;
	h)	usage
			exit
			;;
	?)	usage
			exit 2
			;;
	esac
done

# rewind the option counter to reuse the flags
shift $(($OPTIND - 1))
printf "Remaining arguments are: %s\n" "$*"


# level to lessen priority to leave processor time to applet realtime 
level="12"


################
# 4 views images

if [ "$lineflag" ]
then

	# produces a 4 views line drawing in eps
	objline "$filename".rad | psmeta > "$filename"4.eps

fi
if [ "$viewflag" ]
then

	# produces a 4 views image
	objpict sky.rad material.rad $filename.rad > "$filename"4.hdr
	# convert the 4 view image
	convert "$filename"4.hdr "$filename"4.jpg

fi


##############
# rendering

if [ "$renderflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = render directory
	# $2 = superposition flag for irradiance countour lines
	# $3 = mkillum flag for secondary sources computation
	if [ -z "$3" ]; then 
		echo radiance render usage: radiance.sh -r -f filename dir superposeFlag mkillumFlag
		exit
	fi

	# move to render dir
	cd $1
	pwd

	# compute octree
	oconv sky.rad  material.rad $filename.rad > $filename.oct

	# mkillum computation for secondary sources if requested
	if [ $3 -eq 1 ]; then	
	  echo mkillum computation
	  mkillum param $filename.oct < $filename.rad > i${filename}.rad
	  oconv -i $filename.oct i${filename}.rad > i${filename}.oct
	fi

	#render image with correct viewpoint
	
	echo rendering 
	if [ $3 -eq 1 ]; then	
	  nice -n $level rpict param -vf $filename.vp i${filename}.oct > $filename.hdr
	else
	  nice -n $level rpict param -vf $filename.vp $filename.oct > $filename.hdr	
	fi
	#rpict -vf $filename.vp -x 800 -y 800 -ab 3 -av .2 .2 .2 -aa .15  -ar 128 -ad 512 -as 256 $filename.oct > $filename.hdr

	#filter image
	echo  filtering 
	pfilt param $filename.hdr > ${filename}_f.hdr
	
	# if superposition required generate irradiance picture
	if [ $2 -eq 1 ]; then
	  echo superposition rendering + filtering
	  nice -n $level rpict paramSuper -vf $filename.vp $filename.oct > ${filename}_sup.hdr
	  pfilt param ${filename}_sup.hdr > ${filename}_supf.hdr
	fi  

	# create false color image
	# if superposition required generate false color image super-imposed on regular image
	if [ $2 -eq 1 ]; then
	  echo superposition false color
	  falsecolor param -p ${filename}_supf.hdr -i ${filename}_f.hdr > ${filename}_falseCL.hdr
	else  
	  echo  false color 
	  falsecolor param -ip ${filename}_f.hdr > ${filename}_false.hdr
	fi
	
	echo  converting images 
	#convert images in tif and gif (using radiance conversion tools)
	ra_tiff param ${filename}_f.hdr $filename.tif
	ra_gif  param ${filename}_f.hdr $filename.gif
	if [ $2 -eq 1 ]; then
	  ra_tiff param ${filename}_falseCL.hdr ${filename}_falseCL.tif
	  ra_gif  param ${filename}_falseCL.hdr ${filename}_falseCL.gif
	else
	  ra_tiff param ${filename}_false.hdr ${filename}_false.tif
	  ra_gif  param ${filename}_false.hdr ${filename}_false.gif
	fi

	#convert images in tga and jpg (if ImageMagick present)
	convert param ${filename}_f.hdr $filename.tga
	convert param ${filename}_f.hdr $filename.jpg
	if [ $2 -eq 1 ]; then
	  convert param ${filename}_falseCL.hdr ${filename}_falseCL.tga
	  convert param ${filename}_falseCL.hdr ${filename}_falseCL.jpg
	else
	  convert param ${filename}_false.hdr ${filename}_false.tga
	  convert param ${filename}_false.hdr ${filename}_false.jpg
	fi

	# open images	
	ximage ${filename}_f.hdr &
	if [ $2 -eq 1 ]; then
	  ximage ${filename}_falseCL.hdr &
	else
	  ximage ${filename}_false.hdr &
	fi
fi

##############
# simulation (using rtrace)

if [ "$simflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = interation number
	# $2 = simulation directory
	if [ -z "$2" ]; then 
		echo radiance simulation usage: radiance.sh -s -f filename iterationNo dir I
		exit
	fi

	# temp file for potentially changing files
	tmp="tmp"

	# move to simulation dir
	cd $2
	pwd
	
	echo $filename
	echo $1
	echo $filename_$1
	
	# conversion in octree for radiance calculation 
	nice -n $level oconv sky.rad  material.rad $tmp/${filename}_$1.rad > $tmp/${filename}_$1.oct

	# calculation
	nice -n $level rtrace param $tmp/${filename}_$1.oct < $tmp/${filename}.inp > $tmp/${filename}_$1.out
	#nice -n $level rtrace -h -w -I -ab 1 -ad 1000 -as 250 -dc .9 -dj .66 $tmp/$filename_$1.oct < $tmp/$filename.inp > $tmp/$filename_$1.out
	#nice -n $level rtrace -h -w -I -ab 1 -ad 1000 -as 250 -dc .9 -dj .66 $tmp/$filename_$1.oct < $tmp/$filename.inp | rcalc -e '$1=$3' > $tmp/$filename_$1.out

exit
fi